pysfml11
========

A Python binding for the [SFML](https://www.sfml-dev.org) library, based on [pybind11](https://github.com/pybind/pybind11).

Status
------

`pysfml11` is under development and not yet usable. Contributions are very welcome!

License
-------

`pysfml11` is provided under a BSD-style license that can be found in the LICENSE
file. By using, distributing, or contributing to this project, you agree to the
terms and conditions of this license.
